Cardinality

Enum Cardinality 

#[repr(i32)]
pub enum Cardinality { CARDINALITY_UNSPECIFIED = 0, LOW = 1, MEDIUM = 2, HIGH = 3, UNBOUNDED = 4, }

Variants



CARDINALITY_UNSPECIFIED = 0



LOW = 1



MEDIUM = 2



HIGH = 3



UNBOUNDED = 4

Implementations

Source

impl Cardinality

pub const Unspecified: Cardinality = Self::CARDINALITY_UNSPECIFIED

Short-name alias for CARDINALITY_UNSPECIFIED.

pub const Low: Cardinality = Self::LOW

Short-name alias for LOW.

pub const Medium: Cardinality = Self::MEDIUM

Short-name alias for MEDIUM.

pub const High: Cardinality = Self::HIGH

Short-name alias for HIGH.

pub const Unbounded: Cardinality = Self::UNBOUNDED

Short-name alias for UNBOUNDED.

pub const fn as_str(self) -> &'static str

Stable string label.

pub const fn cap(self) -> u64

Numeric cap: the maximum distinct value count permitted at this level. Returns u64::MAX for Unbounded.

pub const fn is_label_compatible(self) -> bool

True if this cardinality is permitted on a FieldKind::Label field.

pub const fn is_measurement_compatible(self) -> bool

True if this cardinality is permitted on a FieldKind::Measurement field.