#[repr(i32)]pub enum FieldKind {
FIELD_KIND_UNSPECIFIED = 0,
LABEL = 1,
ATTRIBUTE = 2,
MEASUREMENT = 3,
TRACE_ID = 4,
SPAN_ID = 5,
PARENT_SPAN_ID = 6,
TIMESTAMP_NS = 7,
DURATION_NS = 8,
FORENSIC = 9,
}Variants
FIELD_KIND_UNSPECIFIED = 0
LABEL = 1
ATTRIBUTE = 2
MEASUREMENT = 3
TRACE_ID = 4
SPAN_ID = 5
PARENT_SPAN_ID = 6
TIMESTAMP_NS = 7
DURATION_NS = 8
FORENSIC = 9
Implementations
Sourceimpl FieldKind
impl FieldKind
Sourcepub const Unspecified: FieldKind = Self::FIELD_KIND_UNSPECIFIED
pub const Unspecified: FieldKind = Self::FIELD_KIND_UNSPECIFIED
Short-name alias for FIELD_KIND_UNSPECIFIED.
Sourcepub const Measurement: FieldKind = Self::MEASUREMENT
pub const Measurement: FieldKind = Self::MEASUREMENT
Short-name alias for MEASUREMENT.
Sourcepub const ParentSpanId: FieldKind = Self::PARENT_SPAN_ID
pub const ParentSpanId: FieldKind = Self::PARENT_SPAN_ID
Short-name alias for PARENT_SPAN_ID.
Sourcepub const TimestampNs: FieldKind = Self::TIMESTAMP_NS
pub const TimestampNs: FieldKind = Self::TIMESTAMP_NS
Short-name alias for TIMESTAMP_NS.
Sourcepub const DurationNs: FieldKind = Self::DURATION_NS
pub const DurationNs: FieldKind = Self::DURATION_NS
Short-name alias for DURATION_NS.
Sourcepub const fn is_envelope_lifted(self) -> bool
pub const fn is_envelope_lifted(self) -> bool
True if a value of this kind is lifted from the typed payload to a dedicated envelope slot.