push_tail_buffer

Function push_tail_buffer 

pub fn push_tail_buffer(env: &ObsEnvelope)
Push an envelope onto the innermost active scope’s tail buffer (if the scope is a Scope, not a Context). No-op when no frame is active or the active frame is Context. Spec 13  6.