HealthWatcher

Struct HealthWatcher 

pub struct HealthWatcher {
    pub name: String,
}
Bridges a crate::aggregator::MetricsAggregator health report to the alert bus.

On each call to HealthWatcher::poll the watcher queries the aggregator’s health report and fires an alert for any component that is Degraded or Unhealthy.

Fields

name: String

Implementations

Source

impl HealthWatcher

pub fn new(name: impl Into<String>) -> Self

pub fn poll( &self, agg: &MetricsAggregator, bus: &mut AlertBus, now: Timestamp, ) -> usize

Poll the aggregator and fire alerts for degraded / unhealthy components. Returns the number of alerts fired.